@@ -798,7 +798,7 @@ class Race(object):
             for ru in ru_list:
                 try:
                     d[ru.fips].append(ru)
-                except:
+                except KeyError:
                     d[ru.fips] = [ru]
             county_list = []
             for county, units in d.items():
@@ -822,7 +822,7 @@ class Race(object):
                     for result in unit.results:
                         try:
                             cands[result.candidate.ap_polra_number].append(result)
-                        except:
+                        except KeyError:
                             cands[result.candidate.ap_polra_number] = [result]
                 for ap_polra_number, results in cands.items():
                     combined = Result(
@@ -1023,6 +1023,22 @@ COUNTY_CROSSWALK = {
         '33015': 'Rockingham',
         '33017': 'Strafford',
         '33019': 'Sullivan',
+    },
+    'VT': {
+        '50001': 'Addison',
+        '50003': 'Bennington',
+        '50005': 'Caledonia',
+        '50007': 'Chittenden',
+        '50009': 'Essex',
+        '50011': 'Franklin',
+        '50013': 'Grand Isle',
+        '50015': 'Lamoille',
+        '50017': 'Orange',
+        '50019': 'Orleans',
+        '50021': 'Rutland',
+        '50023': 'Washington',
+        '50025': 'Windham',
+        '50027': 'Windsor',
     }
 }
 
